package com.ruoyi.project.business.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.project.business.domain.train.TtTrainTarget;
import com.ruoyi.project.business.domain.vo.train.TrainParticipantReq;
import com.ruoyi.project.business.domain.vo.train.TtTrainTargetVo;

import java.util.List;

/**
 * 考核对象Service接口
 *
 * @author ruoyi
 * @date 2024-06-18
 */
public interface ITtTrainTargetService extends IService<TtTrainTarget> {
    /**
     * 查询考核对象
     *
     * @param id 考核对象主键
     * @return 考核对象
     */
    TtTrainTarget selectTtTrainTargetById(Long id);

    /**
     * 查询考核对象列表
     *
     * @param ttTrainTarget 考核对象
     * @return 考核对象集合
     */
    List<TtTrainTargetVo> selectTtTrainTargetList(TtTrainTarget ttTrainTarget);

    /**
     * 新增考核对象
     *
     * @param ttTrainTarget 考核对象
     * @return 结果
     */
    int insertTtTrainTarget(TtTrainTarget ttTrainTarget);

    /**
     * 修改考核对象
     *
     * @param ttTrainTarget 考核对象
     * @return 结果
     */
    int updateTtTrainTarget(TtTrainTarget ttTrainTarget);

    /**
     * 批量删除考核对象
     *
     * @param ids 需要删除的考核对象主键集合
     * @return 结果
     */
    int deleteTtTrainTargetByIds(Long[] ids);

    /**
     * 删除考核对象信息
     *
     * @param id 考核对象主键
     * @return 结果
     */
    int deleteTtTrainTargetById(Long id);

    int updateEditTargetStatus(TtTrainTarget ttTrainTarget);
}
